@@ -11,6 +11,7 @@ Modules:
     pivotpy.iplots    # Plotly's interactive plotting functions
     pivotpy.sio       # Functions for BZ, POSCAR, KPath etc.
     pivotpy.widgets   # Jupyter widgets apps for output analysis/kpath selection. Very useful in big projectes. 
+    pivotpy.surfaces  # Functions for surface and spin texture analysis
     
 Usage:
 -----
@@ -34,7 +35,7 @@ Links:
 links = """[github](https://github.com/massgh/pivotpy)             
 [docs](https://massgh.github.io/pivotpy/)"""
 
-__version__ = "1.1.12"
+__version__ = "1.2.0"
 
 __all__ = []
 
@@ -78,21 +79,6 @@ rbg_matrix= __np.array([[1,0,0],[0,0,1],[0,1,0]]) # Red, Blue, Green
 swap_bg_matrix = rbg_matrix # Alias for backward compatibility
 cmy_matrix = __np.array([[0,0.5,0.5,1],[0.5,0,0.5,1],[0.5,0.5,0,0.2],[1,1,0.2,0]]) # Generates CMYK color palette
 
-#Backward Compatibility
-__mapping = {
-    'quick_bplot':      'splot_bands',
-    'quick_rgb_lines':  'splot_rgb_lines',
-    'quick_color_lines':'splot_color_lines',
-    'quick_dos_lines':  'splot_dos_lines',
-    'plotly_rgb_lines': 'iplot_dos_lines',
-    'plotly_dos_lines': 'iplot_dos_lines'
-}
-
-for k,v in __mapping.items():
-    _code = f"""def {k}(*args,**kwargs):
-    raise DeprecationWarning("Name {k!r} is deprecated, use Vasprun().{v!r} instead.")"""
-    exec(_code)
-
 
 # Edit rcParams here
 import matplotlib as __mpl
@@ -112,10 +98,13 @@ __mpl.rcParams.update(
 import webbrowser as __wb
 def docs():
     __wb.open('https://massgh.github.io/pivotpy/',new=1)
+
+def example():
+    __wb.open('https://massgh.github.io/pivotpy/Example.html',new=1)
     
 def example_notebook():
     __wb.open('https://colab.research.google.com/github/massgh/pivotpy/blob/master/test.ipynb',new=1)
     
-__all__ = ['docs','example_notebook', 'create_colormap' ,*__all__]
+__all__ = ['docs','example','example_notebook', 'create_colormap' ,*__all__]
     
     
\ No newline at end of file
